| Title: | Materials for Introductory Course on Bayesian Learning |
|---|---|
| Description: | Practicals, data sets, helper functions and interactive 'Shiny' apps used in the introductory course on Bayesian inference at the Valencia International Bayesian Summer School. Installing 'vibass' installs all the other packages used during the course and downloads all necessary materials for working off line. |
| Authors: | VIBASS Team [aut, cph], Facundo Muñoz [ctb, cre] (Cirad, Package developer, ORCID: <https://orcid.org/0000-0002-5061-4241>), Carmen Armero [ctb] (Universitat de València), Anabel Forte [ctb] (Universitat de València), David Conesa [ctb] (Universitat de València), Mark Brewer [ctb] (Biomathematics and Statistics Scotland (BioSS), ORCID: <https://orcid.org/0000-0001-7559-389X>), Virgilio Gómez-Rubio [ctb] (Universidad Castilla-La Mancha, ORCID: <https://orcid.org/0000-0002-4791-3072>) |
| Maintainer: | Facundo Muñoz <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.2 |
| Built: | 2026-06-07 08:04:28 UTC |
| Source: | https://github.com/VABAR/vibass |
App codes that are available for use in [vibass_app()].
available_apps()available_apps()
Character vector.
Character vector with available app codes in the package.
available_apps()available_apps()
Make a table of several summary statistics with proper formatting.
summary_table( mean, var, quant, ic95 = NULL, prop0 = NULL, prop1 = NULL, label, digits = 2, ... )summary_table( mean, var, quant, ic95 = NULL, prop0 = NULL, prop1 = NULL, label, digits = 2, ... )
mean |
Real. |
var |
Real. |
quant |
Named numeric vector. Names must be of the form "xx
numeric xx. As from the output of the function |
ic95 |
Numeric vector. |
prop0 |
Real. |
prop1 |
Real. |
label |
Character. Name of the summarised variable. |
digits |
Integer. Number of decimal places to be used. |
... |
Passed to knitr::kable(). |
The table includes the mean, variance and standard deviation, a vector of 3 quantiles at 0.05, 0.50 and 0.95, a 95 numeric value to be interpreted as a proportion above 0 and 1. All values are rounded to the specified number of decimal places.
A knitr_kable object.
summary_table(mean = 1, var = 1, quant = quantile(1:10, 0:4/4), ic95 = 4:5, prop1 = .6, label = "test")summary_table(mean = 1, var = 1, quant = quantile(1:10, 0:4/4), ic95 = 4:5, prop1 = .6, label = "test")
Launches the Shiny interactive applications for the practicals.
vibass_app(x = NULL)vibass_app(x = NULL)
x |
integer or character interpretable as integer. See [available_apps()] for valid options. |
With no arguments, displays a list of available app codes. Otherwise, lauches the corresponding Shiny app.
vibass_app()vibass_app()
Data for the VIBASS session on linear models. This is a simulated dataset that includes data about children. The variables in the dataset are:
data("Weights")data("Weights")
An object of class "data.frame".
age. Age (in years).
vegetables. Measure of vegetables consumption.
weight. Weight (in kg).
sex. Girl or Boy.
height. Height (in cm).
ethnicity Asian, Black or European.
VIBASS Team.
data(Weights) summary(Weights) # ML estimates lmW <- lm(weight ~ age, data = Weights) summary(lmW)data(Weights) summary(Weights) # ML estimates lmW <- lm(weight ~ age, data = Weights) summary(lmW)